@@ -7,11 +7,11 @@
 #include "Pool.hpp"
 #include <array>
 #include <cassert>
-#include <cstdint>
 #include <limits>
 #include <memory>
 #include "VertexDataSource.hpp"
 #include <unordered_map>
+#include <cinttypes>
 
 namespace quickhull {
 
@@ -35,7 +35,7 @@ namespace quickhull {
 
 		struct Face {
 			size_t m_he;
-			Plane<T> m_P;
+			Plane<T> m_P{};
 			T m_mostDistantPointDist;
 			size_t m_mostDistantPoint;
 			size_t m_visibilityCheckedOnIteration;
