@@ -306,7 +306,7 @@ lxPresentDlg::lxPresentDlg(wxWindow *parent)
 		this->SetIcon(wxIcon(loch_xpm));
 #endif
 
-  this->m_mainFrame = (lxFrame *) parent;
+  this->m_mainFrame = dynamic_cast<lxFrame*>(parent);
   this->m_fileName = wxEmptyString;
 
    
