@@ -1,6 +1,4 @@
-#ifdef __cplusplus
-extern "C" {
-#endif
+#pragma once
 
 typedef struct R2PCTX R2PContext;
 
@@ -9,7 +7,3 @@ extern R2PContext *R2PCreate(int width, int height);
 extern void R2PMakeCurrent(R2PContext * ctx);
 
 extern void R2PDestroy(R2PContext * ctx);
-
-#ifdef __cplusplus
-}
-#endif
