@@ -41,8 +41,8 @@ struct lxSetup {
     cam_orig_center, cam_orig_pos;
   int cam_anaglyph_glasses, m_colormd;
   double cam_dist = 0.0, cam_dir, cam_tilt, cam_width = 0.0,
-    cam_orig_dist = 0.0, cam_orig_dir = 0.0, cam_orig_tilt = 0.0, cam_lens, cam_lens_vfov, cam_lens_vfovr, cam_anaglyph_eyesep,
-    data_limits_diam;
+    cam_orig_dist = 0.0, cam_orig_dir = 0.0, cam_orig_tilt = 0.0, cam_lens = 0.0, cam_lens_vfov = 0.0, cam_lens_vfovr = 0.0, cam_anaglyph_eyesep,
+    data_limits_diam = 0.0;
   bool cam_persp, cam_anaglyph, cam_anaglyph_bw, cam_anaglyph_left;
 
   bool m_vis_centerline = false, m_vis_walls, m_vis_surface, 
