@@ -246,19 +246,19 @@ void thdata::set(thcmd_option_desc cod, char ** args, int argenc, unsigned long
       
     case TT_DATA_FIX:
       if ((indataline & THOP_INLINE) == 0)
-        ththrow("not a command line option -- fix");
+        throw thexception("not a command line option -- fix");
       this->cgroup->set_data_fix(cod.nargs, args);
       break;
       
     case TT_DATA_EQUATE:
       if ((indataline & THOP_INLINE) == 0)
-        ththrow("not a command line option -- equate");
+        throw thexception("not a command line option -- equate");
       this->cgroup->set_data_equate(cod.nargs, args);
       break;
       
     case TT_DATA_FLAGS:
       if ((indataline & THOP_INLINE) == 0)
-        ththrow("not a command line option -- flags");
+        throw thexception("not a command line option -- flags");
       this->cgroup->set_data_flags(cod.nargs, args);
       break;
 
@@ -268,7 +268,7 @@ void thdata::set(thcmd_option_desc cod, char ** args, int argenc, unsigned long
       
     case TT_DATA_STATION:
       if ((indataline & THOP_INLINE) == 0)
-        ththrow("not a command line option -- station");
+        throw thexception("not a command line option -- station");
       this->cgroup->set_data_station(cod.nargs, args, argenc);
       break;
       
@@ -289,18 +289,18 @@ void thdata::set(thcmd_option_desc cod, char ** args, int argenc, unsigned long
       
     case TT_DATA_WALLS:
       if (cod.nargs != 1)
-    	  ththrow("invalid number of option arguments -- walls");
+    	  throw thexception("invalid number of option arguments -- walls");
       this->cgroup->d_walls = thmatch_token(*args, thtt_onoffauto);
       if (this->cgroup->d_walls == TT_UNKNOWN_BOOL)
-    	  ththrow("invalid walls switch -- {}", *args);
+    	  throw thexception(fmt::format("invalid walls switch -- {}", *args));
       break;
       
     case TT_DATA_SHAPE:
       if (cod.nargs != 1)
-    	  ththrow("invalid number of option arguments -- shape");
+    	  throw thexception("invalid number of option arguments -- shape");
       this->cgroup->d_shape = thmatch_token(*args, thtt_dataleg_shape);
       if (this->cgroup->d_shape == TT_DATALEG_SHAPE_UNKNOWN)
-    	  ththrow("unknown shape type -- {}", *args);
+    	  throw thexception(fmt::format("unknown shape type -- {}", *args));
       break;
       
     case TT_DATA_VTRESH:
@@ -309,19 +309,19 @@ void thdata::set(thcmd_option_desc cod, char ** args, int argenc, unsigned long
       
     case TT_DATA_INSTRUMENT:
       if ((indataline & THOP_INLINE) == 0)
-        ththrow("not a command line option -- instrument");
+        throw thexception("not a command line option -- instrument");
       this->set_data_instrument(cod.nargs, args);
       break;
       
     case TT_DATA_SD:
       if ((indataline & THOP_INLINE) == 0)
-        ththrow("not a command line option -- sd");
+        throw thexception("not a command line option -- sd");
       this->cgroup->set_data_sd(cod.nargs, args);
       break;
       
     case TT_DATA_DATA:
       if ((indataline & THOP_INLINE) == 0)
-        ththrow("not a command line option -- data");
+        throw thexception("not a command line option -- data");
       this->cgroup->set_data_data(cod.nargs, args);
       break;
       
@@ -332,7 +332,7 @@ void thdata::set(thcmd_option_desc cod, char ** args, int argenc, unsigned long
     case TT_DATA_GRID_ANGLE:
       this->cgroup->dl_declination_north_grid = true;
       if (this->cgroup->cs == TTCS_LOCAL)
-        ththrow("missing coordinate system specification");
+        throw thexception("missing coordinate system specification");
       this->cgroup->set_data_declination(cod.nargs, args);
       break;
 
@@ -343,19 +343,19 @@ void thdata::set(thcmd_option_desc cod, char ** args, int argenc, unsigned long
       
     case TT_DATA_UNITS:
       if ((indataline & THOP_INLINE) == 0)
-        ththrow("not a command line option -- units");
+        throw thexception("not a command line option -- units");
       this->cgroup->set_data_units(cod.nargs, args);
       break;
       
     case TT_DATA_GRADE:
       if ((indataline & THOP_INLINE) == 0)
-        ththrow("not a command line option -- grade");
+        throw thexception("not a command line option -- grade");
       this->cgroup->set_data_grade(cod.nargs, args);
       break;
         
     case TT_DATA_BREAK:
       if (cod.nargs > 0)
-        ththrow("no arguments allowed after break");
+        throw thexception("no arguments allowed after break");
       this->cgroup->complete_interleaved_data();
       this->cgroup->cd_leg_def = false;
       this->cgroup->d_current = 0;
@@ -363,13 +363,13 @@ void thdata::set(thcmd_option_desc cod, char ** args, int argenc, unsigned long
     
     case TT_DATA_CALIBRATE:
       if ((indataline & THOP_INLINE) == 0)
-        ththrow("not a command line option -- calibrate");
+        throw thexception("not a command line option -- calibrate");
       this->cgroup->set_data_calibration(cod.nargs, args);
       break;
     
     case TT_DATA_TEAM:
       if ((indataline & THOP_INLINE) == 0)
-        ththrow("not a command line option -- team");
+        throw thexception("not a command line option -- team");
       thencode(&(this->db->buff_enc), *args, argenc);
       temp_person.parse(this->db, this->db->buff_enc.get_buffer());
       this->team_set.insert(temp_person);
@@ -399,7 +399,7 @@ void thdata::set(thcmd_option_desc cod, char ** args, int argenc, unsigned long
             case TT_DATALEG_RIGHT:
               break;
             default:
-              ththrow("unknown team role -- {}", args[prole_i]);
+              throw thexception(fmt::format("unknown team role -- {}", args[prole_i]));
               break;
           }
         }
@@ -408,7 +408,7 @@ void thdata::set(thcmd_option_desc cod, char ** args, int argenc, unsigned long
 
     case TT_DATA_DISCOVERY_TEAM:
       if ((indataline & THOP_INLINE) == 0)
-        ththrow("not a command line option -- explo-team");
+        throw thexception("not a command line option -- explo-team");
       thencode(&(this->db->buff_enc), *args, argenc);
       temp_person.parse(this->db, this->db->buff_enc.get_buffer());
       this->discovery_team_set.insert(temp_person);
@@ -568,7 +568,7 @@ void thdata::set_data_calibration(int nargs, char ** args)
 
   nitems = nargs - 1;
   if (nitems > THDATA_MAX_ITEMS)
-    ththrow("too many quantities");
+    throw thexception("too many quantities");
 
   // scan quantities
   bool to_set;
@@ -682,7 +682,7 @@ void thdata::set_data_units(int nargs, char ** args)
 
   nitems = nargs - 1;
   if (nitems > THDATA_MAX_ITEMS)
-    ththrow("too many quantities");
+    throw thexception("too many quantities");
 
   // scan quantities
   bool to_set;
@@ -710,7 +710,7 @@ void thdata::set_data_units(int nargs, char ** args)
           sdtype = 1;
         else {
           if (sdtype != 1)
-            ththrow("incompatible quantity -- {}", args[iit]);
+            throw thexception(fmt::format("incompatible quantity -- {}", args[iit]));
         }
         break;
       case TT_DATALEG_BEARING:
@@ -719,7 +719,7 @@ void thdata::set_data_units(int nargs, char ** args)
           sdtype = 2;
         else {
           if (sdtype != 2)
-            ththrow("incompatible quantity -- {}", args[iit]);
+            throw thexception(fmt::format("incompatible quantity -- {}", args[iit]));
         }
         break;
       default:
@@ -729,7 +729,7 @@ void thdata::set_data_units(int nargs, char ** args)
           break;
         }
         else 
-          ththrow("invalid quantity -- {}",args[iit]);
+          throw thexception(fmt::format("invalid quantity -- {}",args[iit]));
     }
     if (to_set)
       items[iit] = itid;
@@ -788,7 +788,7 @@ void thdata::set_data_units(int nargs, char ** args)
       case TT_DATALEG_BEARING:
         this->dlu_bearing = this->dlu_sdangle;
 				if (this->dlu_bearing.get_units() == TT_TFU_PERC)
-					ththrow("percentage bearing specification not allowed");
+					throw thexception("percentage bearing specification not allowed");
         break;
       case TT_DATALEG_GRADIENT:
         this->dlu_gradient = this->dlu_sdangle;
@@ -822,18 +822,18 @@ void thdata::set_data_vtresh(int nargs, char ** args)
 {
 
   if ((nargs < 1) || (nargs > 2))
-    ththrow("invalid number of option arguments -- vthreshold");
+    throw thexception("invalid number of option arguments -- vthreshold");
   int nid;
   thtfangle dlu;
   thparse_double(nid, this->d_vtresh, args[0]);
   if (nid != TT_SV_NUMBER)
-    ththrow("invalid vthreshold -- {}", args[0]);
+    throw thexception(fmt::format("invalid vthreshold -- {}", args[0]));
   if (nargs > 1) {
     dlu.parse_units(args[1]);
     this->d_vtresh = dlu.transform(this->d_vtresh);
   }
   if ((this->d_vtresh < 0.0) || (this->d_vtresh > 90.0))
-    ththrow("vthreshold out of range -- {}", args[0]);
+    throw thexception(fmt::format("vthreshold out of range -- {}", args[0]));
   
 }
 
@@ -841,7 +841,7 @@ void thdata::set_data_vtresh(int nargs, char ** args)
 void thdata::set_data_declination(int nargs, char ** args)
 {
   if (nargs > 2)
-    ththrow("too many option arguments");
+    throw thexception("too many option arguments");
   int nid;
   thparse_double(nid, this->dl_declination, args[0]);
   if (nargs > 1) {
@@ -850,20 +850,20 @@ void thdata::set_data_declination(int nargs, char ** args)
   }
   else 
     if (nid != TT_SV_NAN)
-      ththrow("missing angular units");
+      throw thexception("missing angular units");
   if ((nid != TT_SV_NUMBER) && (nid != TT_SV_NAN))
-    ththrow("invalid number -- {}", args[0]);
+    throw thexception(fmt::format("invalid number -- {}", args[0]));
 }
   
 void thdata::set_data_infer(int nargs, char ** args)
 {
   if (nargs > 2)
-    ththrow("too many option arguments");
+    throw thexception("too many option arguments");
   int iwhat, ihow;
   iwhat = thmatch_token(args[0],thtt_dataleg_infer);
   ihow = thmatch_token(args[1],thtt_bool);
   if (ihow == TT_UNKNOWN_BOOL)
-    ththrow("invalid boolean argument -- {}", args[1]);
+    throw thexception(fmt::format("invalid boolean argument -- {}", args[1]));
   switch (iwhat) {
     case TT_DATALEG_INFER_EQUATES:
       this->dli_equates = (ihow == TT_TRUE);
@@ -872,7 +872,7 @@ void thdata::set_data_infer(int nargs, char ** args)
       this->dli_plumbs = (ihow == TT_TRUE);
       break;
     default:
-      ththrow("invalid argument -- {}", args[0]);
+      throw thexception(fmt::format("invalid argument -- {}", args[0]));
   }
 }
 
@@ -902,7 +902,7 @@ void thdata::set_data_instrument(int nargs, char ** args)
       case TT_DATALEG_RIGHT:
         break;
       default:
-        ththrow("invalid instrument -- {}", args[i]);
+        throw thexception(fmt::format("invalid instrument -- {}", args[i]));
     }
   }
 }
@@ -915,7 +915,7 @@ void thdata::set_data_sd(int nargs, char ** args)
 
   nitems = nargs - 1;
   if (nitems > THDATA_MAX_ITEMS)
-    ththrow("too many quantities");
+    throw thexception("too many quantities");
 
   // scan quantities
   bool to_set;
@@ -937,7 +937,7 @@ void thdata::set_data_sd(int nargs, char ** args)
           sdtype = 1;
         else {
           if (sdtype != 1)
-            ththrow("incompatible quantity -- {}", args[iit]);
+            throw thexception(fmt::format("incompatible quantity -- {}", args[iit]));
         }
         break;
       case TT_DATALEG_BEARING:
@@ -946,7 +946,7 @@ void thdata::set_data_sd(int nargs, char ** args)
           sdtype = 2;
         else {
           if (sdtype != 2)
-            ththrow("incompatible quantity -- {}", args[iit]);
+            throw thexception(fmt::format("incompatible quantity -- {}", args[iit]));
         }
         break;
       default:
@@ -956,7 +956,7 @@ void thdata::set_data_sd(int nargs, char ** args)
           break;
         }
         else 
-          ththrow("invalid quantity -- {}",args[iit]);
+          throw thexception(fmt::format("invalid quantity -- {}",args[iit]));
     }
     if (to_set)
       items[iit] = itid;
@@ -967,7 +967,7 @@ void thdata::set_data_sd(int nargs, char ** args)
   switch (nid) {
     case TT_SV_NUMBER:
       if (nitems == nargs - 1)
-        ththrow("missing standard deviation units");
+        throw thexception("missing standard deviation units");
       switch (sdtype) {
         case 1:
           this->dlu_sdlength.parse_units(args[nitems+1]);
@@ -983,7 +983,7 @@ void thdata::set_data_sd(int nargs, char ** args)
       break;
     default:
       if (nid != TT_SV_NUMBER)
-        ththrow("invalid value -- {}", args[nitems]);
+        throw thexception(fmt::format("invalid value -- {}", args[nitems]));
   }
   
   // set standard deviations
@@ -1041,11 +1041,11 @@ void thdata::set_data_data(int nargs, char ** args)
   this->reset_data();
   this->d_type = thmatch_token(args[0], thtt_datatype);
   if (this->d_type == TT_DATATYPE_UNKNOWN)
-    ththrow("unknown data type -- {}", args[0]);
+    throw thexception(fmt::format("unknown data type -- {}", args[0]));
     
   // second let's detect data order
   if (nargs > THDATA_MAX_ITEMS)
-    ththrow("too many quantities");
+    throw thexception("too many quantities");
   int dix, idd;
   bool err_duplicate = false, err_inimm = false, err_itype = false,
     err_idanl = false;
@@ -1433,7 +1433,7 @@ void thdata::set_data_data(int nargs, char ** args)
           break;
         }
         if ((dix == 1) || (dix == nargs - 1))
-          ththrow("invalid newline position");
+          throw thexception("invalid newline position");
         this->di_newline = true;
         break;
 
@@ -1492,18 +1492,18 @@ void thdata::set_data_data(int nargs, char ** args)
         break;        
         
       default:
-        ththrow("invalid identifier -- {}", args[dix]);
+        throw thexception(fmt::format("invalid identifier -- {}", args[dix]));
     }
     
     // catch errors
     if (err_duplicate)
-      ththrow("duplicate identifier -- {}", args[dix]);
+      throw thexception(fmt::format("duplicate identifier -- {}", args[dix]));
     if (err_inimm)
-      ththrow("interleaved and non-interleaved reading mix -- {}", args[dix]);
+      throw thexception(fmt::format("interleaved and non-interleaved reading mix -- {}", args[dix]));
     if (err_itype)
-      ththrow("invalid reading for this style -- {}", args[dix]);
+      throw thexception(fmt::format("invalid reading for this style -- {}", args[dix]));
     if (err_idanl)
-      ththrow("interleaved reading after newline -- {}", args[dix]);
+      throw thexception(fmt::format("interleaved reading after newline -- {}", args[dix]));
    
     // if no errors, no ignoreall - set order  
     this->d_order[dix - 1] = idd;
@@ -1544,7 +1544,7 @@ void thdata::set_data_data(int nargs, char ** args)
   all_data = all_data &&
       ((this->di_from && this->di_to) || this->di_station);
   if (!all_data)
-    ththrow("not all data for given style");
+    throw thexception("not all data for given style");
    
   if (this->di_interleaved) {
     for(dix = 0; (!err_inimm) && (dix < this->d_nitems) && (this->d_order[dix] != TT_DATALEG_NEWLINE); dix++) {
@@ -1575,7 +1575,7 @@ void thdata::set_data_data(int nargs, char ** args)
       
     }
     if (err_inimm)
-      ththrow("non-interleaved data before newline -- {}", args[dix]);
+      throw thexception(fmt::format("non-interleaved data before newline -- {}", args[dix]));
   }
     
   
@@ -1592,7 +1592,7 @@ void thdata_parse_dim(const char * src, double & d1, double & d2,
   if (!d2ok) {
     thparse_double(sv, d1, src);
     if ((sv != TT_SV_NUMBER) && (sv != TT_SV_NAN))
-      ththrow("invalid {} reading -- {}", item, src);
+      throw thexception(fmt::format("invalid {} reading -- {}", item, src));
   } else {
     char ** args;
     long nargs;
@@ -1601,29 +1601,29 @@ void thdata_parse_dim(const char * src, double & d1, double & d2,
     nargs = thdb.mbuff_tmp2.get_size();    
     d2ok = false;
     if ((nargs < 1) || (nargs > 2))
-      ththrow("invalid {} reading -- {}", item, src);
+      throw thexception(fmt::format("invalid {} reading -- {}", item, src));
     if (nargs > 1) {
       d2ok = true;
       thparse_double(sv, d2, args[1]);
       if ((sv != TT_SV_NUMBER) && (sv != TT_SV_NAN))
-        ththrow("invalid {} reading -- {}", item, args[1]);
+        throw thexception(fmt::format("invalid {} reading -- {}", item, args[1]));
     }
     thparse_double(sv, d1, args[0]);
     if ((sv != TT_SV_NUMBER) && (sv != TT_SV_NAN))
-      ththrow("invalid {} reading -- {}", item, args[0]);
+      throw thexception(fmt::format("invalid {} reading -- {}", item, args[0]));
   }
   
   if (!thisnan(d1)) {
     d1 = ctran->evaluate(d1);
     d1 = utran->transform(d1);
     if (d1 < 0.0)
-      ththrow("negative {} reading -- {}", item, src);
+      throw thexception(fmt::format("negative {} reading -- {}", item, src));
   }
   if (!thisnan(d2)) {
     d2 = ctran->evaluate(d2);
     d2 = utran->transform(d2);
     if (d2 < 0.0)
-      ththrow("negative {} reading -- {}", item, src);
+      throw thexception(fmt::format("negative {} reading -- {}", item, src));
   }
   
 }
@@ -1736,7 +1736,7 @@ void thdata::insert_data_leg(int nargs, char ** args)
     if ((carg == nargs) && 
         ((this->d_order[this->d_current] != TT_DATALEG_NEWLINE)
          && (this->d_order[this->d_current] != TT_DATALEG_IGNOREALL)))
-      ththrow("not enough data readings");
+      throw thexception("not enough data readings");
   
     switch(this->d_order[this->d_current]) {
     
@@ -1764,7 +1764,7 @@ void thdata::insert_data_leg(int nargs, char ** args)
         if (icase_equals(args[carg],"b"))
           this->cd_leg->direction = false;
         else if (!icase_equals(args[carg], "f"))
-          ththrow("invalid survey direction -- {}", args[carg]);
+          throw thexception(fmt::format("invalid survey direction -- {}", args[carg]));
         break;
         
       case TT_DATALEG_LENGTH:
@@ -1774,7 +1774,7 @@ void thdata::insert_data_leg(int nargs, char ** args)
             val = this->dlc_length.evaluate(val);
             val = this->dlu_length.transform(val);
             if (val < 0.0)
-              ththrow("negative length reading -- {}", args[carg]);
+              throw thexception(fmt::format("negative length reading -- {}", args[carg]));
             else
               this->cd_leg->length = val;
             break;
@@ -1782,7 +1782,7 @@ void thdata::insert_data_leg(int nargs, char ** args)
 //            this->cd_leg->length = val;
 //            break;
           default:
-            ththrow("invalid length reading -- {}", args[carg]);
+            throw thexception(fmt::format("invalid length reading -- {}", args[carg]));
         }
         break;
 
@@ -1793,7 +1793,7 @@ void thdata::insert_data_leg(int nargs, char ** args)
               val = this->dlc_length.evaluate(val);
               val = this->dlu_length.transform(val);
               if (val < 0.0)
-                ththrow("negative length reading -- {}", args[carg]);
+                throw thexception(fmt::format("negative length reading -- {}", args[carg]));
               else
                 this->cd_leg->backlength = val;
               break;
@@ -1801,7 +1801,7 @@ void thdata::insert_data_leg(int nargs, char ** args)
   //            this->cd_leg->length = val;
   //            break;
             default:
-              ththrow("invalid backwards length reading -- {}", args[carg]);
+              throw thexception(fmt::format("invalid backwards length reading -- {}", args[carg]));
           }
           break;
 
@@ -1820,7 +1820,7 @@ void thdata::insert_data_leg(int nargs, char ** args)
             if (val >= 360.0)
               val -= 360.0;
             if ((val < 0.0) || (val >= 360.0))
-              ththrow("bearing reading out of range -- {}", args[carg]);
+              throw thexception(fmt::format("bearing reading out of range -- {}", args[carg]));
             else
               this->cd_leg->bearing = val;
             break;
@@ -1828,7 +1828,7 @@ void thdata::insert_data_leg(int nargs, char ** args)
             this->cd_leg->bearing = val;
             break;
           default:
-            ththrow("invalid bearing reading -- {}", args[carg]);
+            throw thexception(fmt::format("invalid bearing reading -- {}", args[carg]));
         }
         break;
         
@@ -1846,7 +1846,7 @@ void thdata::insert_data_leg(int nargs, char ** args)
             if (val >= 360.0)
               val -= 360.0;
             if ((val < 0.0) || (val >= 360.0))
-              ththrow("backwards bearing reading out of range -- {}", args[carg]);
+              throw thexception(fmt::format("backwards bearing reading out of range -- {}", args[carg]));
             else
               this->cd_leg->backbearing = val;
             break;
@@ -1854,7 +1854,7 @@ void thdata::insert_data_leg(int nargs, char ** args)
             this->cd_leg->backbearing = val;
             break;
           default:
-            ththrow("invalid backwards bearing reading -- {}", args[carg]);
+            throw thexception(fmt::format("invalid backwards bearing reading -- {}", args[carg]));
         }
         break;
         
@@ -1870,7 +1870,7 @@ void thdata::insert_data_leg(int nargs, char ** args)
             if ((val >= 269.99999) && (val <= 360.00001))
             	val -= 360.0;
             if ((val <= -90.00001) || (val >= 90.00001))
-              ththrow("gradient reading out of range -- {}", args[carg]);
+              throw thexception(fmt::format("gradient reading out of range -- {}", args[carg]));
             else {
               if (val < -90.0) val = -90.0;
               if (val >  90.0) val =  90.0;
@@ -1883,7 +1883,7 @@ void thdata::insert_data_leg(int nargs, char ** args)
             this->cd_leg->gradient = val;
             break;
           default:
-            ththrow("invalid gradient reading -- {}", args[carg]);
+            throw thexception(fmt::format("invalid gradient reading -- {}", args[carg]));
         }
         break;
         
@@ -1897,7 +1897,7 @@ void thdata::insert_data_leg(int nargs, char ** args)
             val = this->dlc_gradient.evaluate(val);
             val = this->dlu_gradient.transform(val);
             if ((val <= -90.00001) || (val >= 90.00001))
-              ththrow("backwards gradient reading out of range -- {}", args[carg]);
+              throw thexception(fmt::format("backwards gradient reading out of range -- {}", args[carg]));
             else
               this->cd_leg->backgradient = val;
             break;
@@ -1907,7 +1907,7 @@ void thdata::insert_data_leg(int nargs, char ** args)
             this->cd_leg->backgradient = val;
             break;
           default:
-            ththrow("invalid backwards gradient reading -- {}", args[carg]);
+            throw thexception(fmt::format("invalid backwards gradient reading -- {}", args[carg]));
         }
         break;
         
@@ -1918,7 +1918,7 @@ void thdata::insert_data_leg(int nargs, char ** args)
             val = this->dlc_counter.evaluate(val);
             val = this->dlu_counter.transform(val);
             if (val < 0.0)
-              ththrow("negative counter reading -- {}", args[carg]);
+              throw thexception(fmt::format("negative counter reading -- {}", args[carg]));
             else
               this->cd_leg->counter = val;
             break;
@@ -1926,7 +1926,7 @@ void thdata::insert_data_leg(int nargs, char ** args)
 //            this->cd_leg->counter = val;
 //            break;
           default:
-            ththrow("invalid counter reading -- {}", args[carg]);
+            throw thexception(fmt::format("invalid counter reading -- {}", args[carg]));
         }
         break;
         
@@ -1942,7 +1942,7 @@ void thdata::insert_data_leg(int nargs, char ** args)
 //            this->cd_leg->fromcounter = val;
 //            break;
           default:
-            ththrow("invalid counter reading -- {}", args[carg]);
+            throw thexception(fmt::format("invalid counter reading -- {}", args[carg]));
         }
         break;
         
@@ -1958,7 +1958,7 @@ void thdata::insert_data_leg(int nargs, char ** args)
 //            this->cd_leg->tocounter = val;
 //            break;
           default:
-            ththrow("invalid counter reading -- {}", args[carg]);
+            throw thexception(fmt::format("invalid counter reading -- {}", args[carg]));
         }
         break;
         
@@ -1974,7 +1974,7 @@ void thdata::insert_data_leg(int nargs, char ** args)
 //            this->cd_leg->depth = val;
 //            break;
           default:
-            ththrow("invalid depth reading -- {}", args[carg]);
+            throw thexception(fmt::format("invalid depth reading -- {}", args[carg]));
         }
         break;
         
@@ -1990,7 +1990,7 @@ void thdata::insert_data_leg(int nargs, char ** args)
 //            this->cd_leg->fromdepth = val;
 //            break;
           default:
-            ththrow("invalid depth reading -- {}", args[carg]);
+            throw thexception(fmt::format("invalid depth reading -- {}", args[carg]));
         }
         break;
         
@@ -2006,7 +2006,7 @@ void thdata::insert_data_leg(int nargs, char ** args)
 //            this->cd_leg->todepth = val;
 //            break;
           default:
-            ththrow("invalid depth reading -- {}", args[carg]);
+            throw thexception(fmt::format("invalid depth reading -- {}", args[carg]));
         }
         break;
         
@@ -2022,7 +2022,7 @@ void thdata::insert_data_leg(int nargs, char ** args)
 //            this->cd_leg->depthchange = val;
 //            break;
           default:
-            ththrow("invalid depth change reading -- {}", args[carg]);
+            throw thexception(fmt::format("invalid depth change reading -- {}", args[carg]));
         }
         break;
         
@@ -2038,7 +2038,7 @@ void thdata::insert_data_leg(int nargs, char ** args)
 //            this->cd_leg->dy = val;
 //            break;
           default:
-            ththrow("invalid northing reading -- {}", args[carg]);
+            throw thexception(fmt::format("invalid northing reading -- {}", args[carg]));
         }
         break;
         
@@ -2054,7 +2054,7 @@ void thdata::insert_data_leg(int nargs, char ** args)
 //            this->cd_leg->dx = val;
 //            break;
           default:
-            ththrow("invalid easting reading -- {}", args[carg]);
+            throw thexception(fmt::format("invalid easting reading -- {}", args[carg]));
         }
         break;
         
@@ -2070,7 +2070,7 @@ void thdata::insert_data_leg(int nargs, char ** args)
 //            this->cd_leg->dz = val;
 //            break;
           default:
-            ththrow("invalid altitude reading -- {}", args[carg]);
+            throw thexception(fmt::format("invalid altitude reading -- {}", args[carg]));
         }
         break;
         
@@ -2166,12 +2166,12 @@ void thdata::insert_data_leg(int nargs, char ** args)
   }  // end of data setting
   
   if (carg < nargs)
-    ththrow("too many data readings");
+    throw thexception("too many data readings");
   
   if (to_clear) {
     if (this->di_fromcount && this->di_tocount && 
       (this->cd_leg->fromcounter > this->cd_leg->tocounter))
-      ththrow("negative counter difference");
+      throw thexception("negative counter difference");
 //    if ((this->di_gradient || this->di_backgradient) && (this->di_bearing || this->di_backbearing) &&
 //      (!(thisnan(this->cd_leg->bearing) 
 //      && thisnan(this->cd_leg->backbearing))) &&
@@ -2183,7 +2183,7 @@ void thdata::insert_data_leg(int nargs, char ** args)
       (thisinf(this->cd_leg->backgradient) == 0)) ||
       ((thisinf(this->cd_leg->gradient) == 0) &&
       (thisinf(this->cd_leg->backgradient) != 0))))
-      ththrow("plumbed shot with a gradient reading");
+      throw thexception("plumbed shot with a gradient reading");
     this->d_current = 0;
     this->complete_interleaved_data();
   }
@@ -2234,7 +2234,7 @@ void thdata::complete_interleaved_data()
     if ((!thisnan(this->pd_leg->fromcounter)) &&
       (!thisnan(this->pd_leg->tocounter)) &&
       (this->pd_leg->fromcounter > this->pd_leg->tocounter))
-      ththrow("negative counter difference");
+      throw thexception("negative counter difference");
   }
   
   // set the depth
@@ -2251,7 +2251,7 @@ void thdata::complete_interleaved_data()
 void thdata::start_insert()
 {
   if (this->cgroup->ugroup != NULL)
-    ththrow("missing endgroup");
+    throw thexception("missing endgroup");
   this->complete_interleaved_data();
 }
 
@@ -2270,7 +2270,7 @@ void thdata::set_data_fix(int nargs, char ** args)
 //    case 10:
       break;
     default:
-      ththrow("invalid number of fix option arguments");
+      throw thexception("invalid number of fix option arguments");
   }
   it = this->fix_list.insert(this->fix_list.end(),dumm);
   it->srcf = this->db->csrc;
@@ -2284,7 +2284,7 @@ void thdata::set_data_fix(int nargs, char ** args)
     if (ai > 2) {
       thparse_double(vid, val, args[ai]);
       if (vid != TT_SV_NUMBER)
-        ththrow("invalid number -- {}", args[ai]);
+        throw thexception(fmt::format("invalid number -- {}", args[ai]));
     }
     switch (ai) {
       case 0:
@@ -2312,7 +2312,7 @@ void thdata::set_data_fix(int nargs, char ** args)
       case 4:
         val = this->dlu_x.transform(val);
         if (val <= 0.0) {
-          ththrow("standard deviation must be positive -- {}", args[ai]);
+          throw thexception(fmt::format("standard deviation must be positive -- {}", args[ai]));
         }
         it->sdx = val;
         it->sdy = val;
@@ -2322,14 +2322,14 @@ void thdata::set_data_fix(int nargs, char ** args)
         if (nargs == 6) {
           val = this->dlu_z.transform(val);
           if (val <= 0.0) {
-            ththrow("standard deviation must be positive -- {}", args[ai]);
+            throw thexception(fmt::format("standard deviation must be positive -- {}", args[ai]));
           }
           it->sdz = val;
         }
         else {
           val = this->dlu_y.transform(val);
           if (val <= 0.0) {
-            ththrow("standard deviation must be positive -- {}", args[ai]);
+            throw thexception(fmt::format("standard deviation must be positive -- {}", args[ai]));
           }
           it->sdy = val;
         }
@@ -2337,7 +2337,7 @@ void thdata::set_data_fix(int nargs, char ** args)
       case 6:
         val = this->dlu_z.transform(val);
         if (val <= 0.0) {
-          ththrow("standard deviation must be positive -- {}", args[ai]);
+          throw thexception(fmt::format("standard deviation must be positive -- {}", args[ai]));
         }
         it->sdz = val;
         break;
@@ -2437,7 +2437,7 @@ void thdata::set_data_station(int nargs, char ** args, int argenc)
             if (notflag)
                 it->flags |= TT_STATIONFLAG_NOTFIXED;
             else
-              ththrow("you can not set fixed station flag directly - fix command needs to be used for this");
+              throw thexception("you can not set fixed station flag directly - fix command needs to be used for this");
             break;
           case TT_DATASFLAG_CONT:
             if (notflag) {
@@ -2465,40 +2465,40 @@ void thdata::set_data_station(int nargs, char ** args, int argenc)
           //  break;
           case TT_DATASFLAG_EXPLORED:
             if ((it->flags & TT_STATIONFLAG_CONT) == 0)
-              ththrow("missing continuation flag before explored length");
+              throw thexception("missing continuation flag before explored length");
             if (notflag) {
                 it->explored = thnan;
                 break;
             }
             if ((ai + 1) == nargs)
-              ththrow("too few flags - missing explored length");
+              throw thexception("too few flags - missing explored length");
             ai++;
             if (strlen(args[ai]) == 0) {
               it->explored = thnan;
             } else {
 	            thparse_length(sv, it->explored, args[ai]);
 	            if (sv == TT_SV_UNKNOWN)
-                      ththrow("invalid explored length specification -- {}", args[ai]);
+                      throw thexception(fmt::format("invalid explored length specification -- {}", args[ai]));
             }
             break;
 
           case TT_DATASFLAG_ATTR:              
             if ((ai + 1) == nargs)
-              ththrow("too few flags - missing attribute name");
+              throw thexception("too few flags - missing attribute name");
             ai++;
             if (strlen(args[ai]) == 0)
-              ththrow("empty attribute name not allowed");
+              throw thexception("empty attribute name not allowed");
             if (args[ai][0] == '_')
-              ththrow("attribute name starting with '_' not allowed -- {}", args[ai]);
+              throw thexception(fmt::format("attribute name starting with '_' not allowed -- {}", args[ai]));
             if (!th_is_attr_name(args[ai]))
-              ththrow("invalid characters in attribute name -- {}", args[ai]);
+              throw thexception(fmt::format("invalid characters in attribute name -- {}", args[ai]));
             attrname = args[ai];
             if (notflag) {
                 it->attr.erase(attrname);
                 break;
             }
             if ((ai + 1) == nargs)
-              ththrow("too few flags - missing attribute value");
+              throw thexception("too few flags - missing attribute value");
             ai++;            
             if (strlen(args[ai]) > 0) {
               thencode(&(this->db->buff_enc), args[ai], argenc);
@@ -2511,7 +2511,7 @@ void thdata::set_data_station(int nargs, char ** args, int argenc)
           case TT_DATASFLAG_NOT:
             break;
           default:
-            ththrow("invalid station flag -- {}", args[ai]);
+            throw thexception(fmt::format("invalid station flag -- {}", args[ai]));
         }
         if (fid == TT_DATASFLAG_NOT)
             notflag = true;
@@ -2534,7 +2534,7 @@ void thdata::set_data_flags(int nargs, char ** args)
         if ((fid < nargs - 1) && (!notb))
           notb = true;
         else
-          ththrow("wrong not context");
+          throw thexception("wrong not context");
         break;
       case TT_DATALFLAG_SURFACE:
         if (notb)
@@ -2565,7 +2565,7 @@ void thdata::set_data_flags(int nargs, char ** args)
         notb = false;
         break;
       default:
-        ththrow("unknown leg flag -- {}", args[fid]);
+        throw thexception(fmt::format("unknown leg flag -- {}", args[fid]));
     }
   }
 }
@@ -2587,7 +2587,7 @@ void thdata::set_data_extend(int nargs, char ** args)
 	    thparse_double(exn, tmpdbl, args[0]);
 		  if (exn == TT_SV_NUMBER) {
 			  if ((tmpdbl < 0.0) || (tmpdbl > 200.0))
-				  ththrow("extend ratio out of range [0..200] -- {}", args[0]);
+				  throw thexception(fmt::format("extend ratio out of range [0..200] -- {}", args[0]));
 				ratio_ok = true;
         if (nargs == 1) {
           this->d_extend_ratio = tmpdbl / 100.0;
@@ -2598,7 +2598,7 @@ void thdata::set_data_extend(int nargs, char ** args)
 		  }
 	  }
 	  if (!ratio_ok)
-	    ththrow("unknown extend flag -- {}", args[0]);
+	    throw thexception(fmt::format("unknown extend flag -- {}", args[0]));
   }
   switch (nargs) {
     case 1:
@@ -2625,7 +2625,7 @@ void thdata::set_data_extend(int nargs, char ** args)
       this->extend_list.insert(this->extend_list.end(), dumm);
       break;
     default:
-      ththrow("invalid extend specification");
+      throw thexception("invalid extend specification");
   }
 
 
@@ -2635,11 +2635,11 @@ void thdata::set_data_extend(int nargs, char ** args)
 void thdata::set_data_mark(int nargs, char ** args)
 {
   if (nargs < 1)
-	  ththrow("missing option arguments -- mark");
+	  throw thexception("missing option arguments -- mark");
 
   int tmp_mark = thmatch_token(args[nargs - 1], thtt_datamark);
 	if (tmp_mark == TT_DATAMARK_UNKNOWN) {
-	  ththrow("unknown type of station mark -- {}", args[nargs - 1]);
+	  throw thexception(fmt::format("unknown type of station mark -- {}", args[nargs - 1]));
 	}
 		
   if (nargs > 1) {
@@ -2668,7 +2668,7 @@ void thdata::set_data_grade(int nargs, char ** args)
     if (cgrd != NULL)
       cgrd->update_data_sd(this);
     else
-      ththrow("unknown survey grade -- {}", args[gid]);
+      throw thexception(fmt::format("unknown survey grade -- {}", args[gid]));
   }
 }
 
@@ -2861,7 +2861,7 @@ void thdata::start_group() {
 
 void thdata::end_group() {
   if (this->cgroup->ugroup == NULL) {
-    ththrow("endgroup without startgroup");
+    throw thexception("endgroup without startgroup");
   }
   thdata * tmp = this->cgroup;
   this->cgroup = this->cgroup->ugroup;
