@@ -36,6 +36,8 @@
 #include "thcs.h"
 #include "thdatabase.h"
 
+#include <fmt/core.h>
+
 thdataobject::thdataobject()
 {
   this->db = NULL;
@@ -156,7 +158,7 @@ void thdataobject::set(thcmd_option_desc cod, char ** args, int argenc, unsigned
       if (th_is_extkeyword(*args))
         this->name = this->db->strstore(*args);
       else 
-        ththrow("invalid keyword -- {}", *args);
+        throw thexception(fmt::format("invalid keyword -- {}", *args));
       break;
 
     case TT_DATAOBJECT_CS:
@@ -168,13 +170,13 @@ void thdataobject::set(thcmd_option_desc cod, char ** args, int argenc, unsigned
         case TT_SCRAP_CMD:
           break;
         default:
-          ththrow("coordinate system specification not valid for {}", this->get_cmd_name());
+          throw thexception(fmt::format("coordinate system specification not valid for {}", this->get_cmd_name()));
           break;  
       }
       {
         int id = thcs_parse(*args);
         if (id == TTCS_UNKNOWN) {
-          ththrow("unknown coordinate system -- {}", *args);
+          throw thexception(fmt::format("unknown coordinate system -- {}", *args));
         }
         if (this->get_class_id() != TT_DATA_CMD) {
           this->cs = id;
@@ -183,7 +185,7 @@ void thdataobject::set(thcmd_option_desc cod, char ** args, int argenc, unsigned
           thdata * cobj;
           cobj = dynamic_cast<thdata*>(this);
           if (cobj->cgroup->dl_declination_north_grid && (id == TTCS_LOCAL))
-            ththrow("grid-angle has been defined -- local CS not allowed");
+            throw thexception("grid-angle has been defined -- local CS not allowed");
           cobj->cgroup->cs = id;
           cobj->cgroup->cs_source = this->db->csrc;
         }
@@ -196,7 +198,7 @@ void thdataobject::set(thcmd_option_desc cod, char ** args, int argenc, unsigned
         case TT_SCRAP_CMD:
           break;
         default:
-          ththrow("station-names specification not valid for {}", this->get_cmd_name());
+          throw thexception(fmt::format("station-names specification not valid for {}", this->get_cmd_name()));
           break;  
       }
       if (strlen(args[0]) == 0)
@@ -218,12 +220,12 @@ void thdataobject::set(thcmd_option_desc cod, char ** args, int argenc, unsigned
         case TT_GRADE_CMD:
         case TT_LAYOUT_CMD:
           if (cod.nargs > 1)
-            ththrow("multiple option arguments -- title");
+            throw thexception("multiple option arguments -- title");
           thencode(&(this->db->buff_enc), *args, argenc);
           this->title = this->db->strstore(this->db->buff_enc.get_buffer());
           break;
         default:
-          ththrow("title specification not allowed for this object");
+          throw thexception("title specification not allowed for this object");
           break;
       }
       break;
@@ -233,7 +235,7 @@ void thdataobject::set(thcmd_option_desc cod, char ** args, int argenc, unsigned
         case TT_DATA_CMD:
         case TT_SCRAP_CMD:
           if (cod.nargs > 2)
-            ththrow("too many option arguments -- author");
+            throw thexception("too many option arguments -- author");
           this->dotmp_date.parse(args[0]);
           thencode(&(this->db->buff_enc), args[1], argenc);
           this->dotmp_person.parse(this->db, this->db->buff_enc.get_buffer());
@@ -242,7 +244,7 @@ void thdataobject::set(thcmd_option_desc cod, char ** args, int argenc, unsigned
           this->author_map[this->dotmp_author].join(this->dotmp_date);
           break;
         default:
-          ththrow("author specification not allowed for this object");
+          throw thexception("author specification not allowed for this object");
           break;
       }
       break;
@@ -252,7 +254,7 @@ void thdataobject::set(thcmd_option_desc cod, char ** args, int argenc, unsigned
         case TT_DATA_CMD:
         case TT_SCRAP_CMD:
           if (cod.nargs > 2)
-            ththrow("too many option arguments -- copyright");
+            throw thexception("too many option arguments -- copyright");
           this->dotmp_date.parse(args[0]);
           thencode(&(this->db->buff_enc), args[1], argenc);
           this->dotmp_copyright = 
@@ -262,7 +264,7 @@ void thdataobject::set(thcmd_option_desc cod, char ** args, int argenc, unsigned
           this->copyright_map[this->dotmp_copyright].join(this->dotmp_date);
           break;
         default:
-          ththrow("copyright specification not allowed for this object");
+          throw thexception("copyright specification not allowed for this object");
           break;
       }
       break;
@@ -270,17 +272,17 @@ void thdataobject::set(thcmd_option_desc cod, char ** args, int argenc, unsigned
     case TT_DATAOBJECT_ATTR:
       switch (this->get_class_id()) {
         case TT_LAYOUT_CMD:
-          ththrow("attribute specification not valid for layout");
+          throw thexception("attribute specification not valid for layout");
           break;
       }
       if (cod.nargs != 2)
-        ththrow("invalid attribute specification -- should be <name> <value>");
+        throw thexception("invalid attribute specification -- should be <name> <value>");
       thencode(&(this->db->buff_enc), args[1], argenc);
       this->parse_attribute(args[0], this->db->buff_enc.get_buffer());
       break;
         
     default:
-      ththrow("unknown option -- {}", args[0]);
+      throw thexception(fmt::format("unknown option -- {}", args[0]));
 
   }
 }
@@ -410,7 +412,7 @@ void thdataobject::read_cs(char * src_x, char * src_y, double & dst_x, double &
 	  if (thcfg.outcs_def.is_valid()) {
 	    if (((this->cs == TTCS_LOCAL) && (thcfg.outcs != TTCS_LOCAL)) ||
 	      ((this->cs != TTCS_LOCAL) && (thcfg.outcs == TTCS_LOCAL)))
-	        ththrow("mixing local and global coordinate systems not allowed -- {} [{}] conflict with cs specification at {} [{}]", this->source.name, this->source.line, thcfg.outcs_def.name, thcfg.outcs_def.line);
+	        throw thexception(fmt::format("mixing local and global coordinate systems not allowed -- {} [{}] conflict with cs specification at {} [{}]", this->source.name, this->source.line, thcfg.outcs_def.name, thcfg.outcs_def.line));
 	  };
 
 	  // 1. Conversion to numbers.
@@ -423,7 +425,7 @@ void thdataobject::read_cs(char * src_x, char * src_y, double & dst_x, double &
 	    thparse_double(sv, tx, src_x);
 	  }
 	  if (sv != TT_SV_NUMBER)
-	    ththrow("invalid X coordinate -- {}", src_x);
+	    throw thexception(fmt::format("invalid X coordinate -- {}", src_x));
 
 	  if ((this->cs != TTCS_LOCAL) && thcs_get_data(this->cs)->dms) {
 	    thparse_double_dms(sv, ty, src_y);
@@ -432,7 +434,7 @@ void thdataobject::read_cs(char * src_x, char * src_y, double & dst_x, double &
 	    thparse_double(sv, ty, src_y);
 	  }
 	  if (sv != TT_SV_NUMBER)
-	    ththrow("invalid Y coordinate -- {}", src_y);
+	    throw thexception(fmt::format("invalid Y coordinate -- {}", src_y));
 
 	  if ((this->cs != TTCS_LOCAL) && thcs_get_data(this->cs)->swap) {
 	    tz = tx;
@@ -443,10 +445,10 @@ void thdataobject::read_cs(char * src_x, char * src_y, double & dst_x, double &
 
 	  if ((this->cs != TTCS_LOCAL) && thcs_get_data(this->cs)->dms) {
 	    if ((tx < - THPI) || (tx > THPI))
-	      ththrow("longitude out of range -- {}", thcs_get_data(this->cs)->swap ? src_y : src_x);
+	      throw thexception(fmt::format("longitude out of range -- {}", thcs_get_data(this->cs)->swap ? src_y : src_x));
 
 	    if ((ty < (- THPI / 2)) || (ty > (THPI / 2)))
-	      ththrow("latitude out of range -- {}", thcs_get_data(this->cs)->swap ? src_x : src_y);
+	      throw thexception(fmt::format("latitude out of range -- {}", thcs_get_data(this->cs)->swap ? src_x : src_y));
 	  }
 
 	  dst_x = tx;
@@ -505,7 +507,7 @@ void thdataobject::convert_cs(int src_cs, double src_x, double src_y, double & d
     dst_z = tz;
   } else {
 	if (thcfg.outcs == TTCS_LOCAL)
-      ththrow("mixing local and global coordinate systems not allowed -- {} [{}] conflict with cs specification at {} [{}]", this->source.name, this->source.line, thcfg.outcs_def.name, thcfg.outcs_def.line);
+      throw thexception(fmt::format("mixing local and global coordinate systems not allowed -- {} [{}] conflict with cs specification at {} [{}]", this->source.name, this->source.line, thcfg.outcs_def.name, thcfg.outcs_def.line));
     thcs2cs(src_cs, thcfg.outcs, tx, ty, tz, dst_x, dst_y, dst_z);
   }
 
@@ -530,11 +532,11 @@ void thdataobject::parse_attribute(char * name, char * value) {
 
   // check name
   if ((name == NULL) || (strlen(name) == 0))
-    ththrow("empty attribute name not allowed");
+    throw thexception("empty attribute name not allowed");
   if (name[0] == '_')
-    ththrow("attribute name starting with '_' not allowed");
+    throw thexception("attribute name starting with '_' not allowed");
   if (!th_is_attr_name(name))
-    ththrow("invalid characters in attribute name -- {}", name);
+    throw thexception(fmt::format("invalid characters in attribute name -- {}", name));
 
   this->db->attr.insert_attribute(name, value, long(this->id));
 }
