@@ -31,6 +31,8 @@
 #include "thdataobject.h"
 #include "thdatabase.h"
 
+#include <fmt/core.h>
+
 unsigned long thdatareader_get_opos(bool inlineid, bool cfgid)
 {
   unsigned long opos = 0;
@@ -120,8 +122,8 @@ void thdatareader::read(const char * ifname, long lnstart, long lnend, const cha
         if (optd.id != TT_DATAOBJECT_UNKNOWN) {
           thsplit_args(&this->mbf1, this->bf2.get_buffer());
           if (this->mbf1.get_size() < optd.nargs)
-            ththrow("not enough option arguments -- {} -- must be {}",
-              this->bf1.get_buffer(), optd.nargs);
+            throw thexception(fmt::format("not enough option arguments -- {} -- must be {}",
+              this->bf1.get_buffer(), optd.nargs));
           optd.nargs = this->mbf1.get_size();
           objptr->set(optd, this->mbf1.get_buffer(), 
             this->inp.get_cif_encoding(),
@@ -159,13 +161,13 @@ void thdatareader::read(const char * ifname, long lnstart, long lnend, const cha
           unique_objptr = dbptr->create(this->inp.get_cmd(), osrc);
           objptr = unique_objptr.get();
           if (objptr == NULL)
-            ththrow("unknown command -- {}", this->inp.get_cmd());
+            throw thexception(fmt::format("unknown command -- {}", this->inp.get_cmd()));
           else
             dbptr->check_context(objptr);
             
 	        switch(objptr->get_class_id()) {
             case TT_LAYOUT_CMD:
-              ththrow("layout definition not allowed in input files");
+              throw thexception("layout definition not allowed in input files");
               break;
           }
         }
@@ -176,14 +178,14 @@ void thdatareader::read(const char * ifname, long lnstart, long lnend, const cha
           // let's find an object
           objptr = dbptr->revise(*opts, dbptr->get_current_survey(), osrc);
           if (objptr == NULL)
-            ththrow("object does not exist -- {}", *opts);
+            throw thexception(fmt::format("object does not exist -- {}", *opts));
           ai = 1;
           opts++;
         }
         else {
           if (ant < objptr->get_cmd_nargs())
-            ththrow("not enough command arguments -- must be {}",
-              objptr->get_cmd_nargs());
+            throw thexception(fmt::format("not enough command arguments -- must be {}",
+              objptr->get_cmd_nargs()));
           optd.nargs = 1;
 
           // set obligatory arguments
@@ -199,14 +201,14 @@ void thdatareader::read(const char * ifname, long lnstart, long lnend, const cha
         while (ait < ant) {
           optd = objptr->get_cmd_option_desc(*opts + 1);
           if (configure_cmd && (optd.id == TT_DATAOBJECT_NAME))
-            ththrow("object name configuration not allowed");
+            throw thexception("object name configuration not allowed");
           if (optd.id == TT_DATAOBJECT_UNKNOWN) {
             optd.id = ++ai;
             optd.nargs = 1;
           }
           else {
             if ((ait + optd.nargs) >= ant)
-              ththrow("not enough option arguments -- {} -- must be {}", *opts, optd.nargs);
+              throw thexception(fmt::format("not enough option arguments -- {} -- must be {}", *opts, optd.nargs));
             opts++;
             ait++;
           }
@@ -239,8 +241,8 @@ void thdatareader::read(const char * ifname, long lnstart, long lnend, const cha
 
   }
 // put everything into try block and throw exception, if error
-  catch (...) {
-    threthrow("{} [{}]", this->inp.get_cif_name(), this->inp.get_cif_line_number());
+  catch (const std::exception& e) {
+    throw thexception(fmt::format("{} [{}]", this->inp.get_cif_name(), this->inp.get_cif_line_number()), e);
   }
 
   dbptr->end_insert();  
