@@ -27,6 +27,9 @@
  
 #include "thdate.h"
 #include "thexception.h"
+
+#include <fmt/core.h>
+
 #include <time.h>
 #include <locale.h>
 
@@ -110,7 +113,7 @@ void thdate::parse(const char * src)
           (ppos == 7) || (ppos == 8) || (ppos == 12))
         ppos++;
       else
-        ththrow("invalid date syntax -- \"{}\"", osrc);
+        throw thexception(fmt::format("invalid date syntax -- \"{}\"", osrc));
       ssrc++;
       continue;
     }
@@ -120,7 +123,7 @@ void thdate::parse(const char * src)
           (ppos == 10) || (ppos == 11))
         ppos++;
       else
-        ththrow("invalid date syntax -- \"{}\"", osrc);
+        throw thexception(fmt::format("invalid date syntax -- \"{}\"", osrc));
       ssrc++;
       continue;
     }
@@ -132,7 +135,7 @@ void thdate::parse(const char * src)
         if ((ppos >= 7) && (ppos <= 9))
           ppos = 10;
         else
-          ththrow("invalid date syntax -- \"{}\"", osrc);
+          throw thexception(fmt::format("invalid date syntax -- \"{}\"", osrc));
       }
       ssrc++;
       continue;
@@ -142,7 +145,7 @@ void thdate::parse(const char * src)
       if ((ppos >= 0) && (ppos <= 6))
         ppos = 7;
       else
-        ththrow("invalid date syntax -- \"{}\"", osrc);
+        throw thexception(fmt::format("invalid date syntax -- \"{}\"", osrc));
       ssrc++;
       continue;
     }
@@ -170,11 +173,11 @@ void thdate::parse(const char * src)
       continue;
     }
     else
-      ththrow("invalid date syntax -- \"{}\"", osrc);
+      throw thexception(fmt::format("invalid date syntax -- \"{}\"", osrc));
   }  // while
   
   if (dd[0] < 0)
-    ththrow("invalid date year -- \"{}\"", osrc);
+    throw thexception(fmt::format("invalid date year -- \"{}\"", osrc));
   else
     this->syear = dd[0];
     
@@ -182,35 +185,35 @@ void thdate::parse(const char * src)
     if (dd[1] < 13)
       this->smonth = dd[1];
     else
-      ththrow("invalid date month -- \"{}\"", osrc);
+      throw thexception(fmt::format("invalid date month -- \"{}\"", osrc));
   }
   
   if (dd[2] > 0) {
     if ((dd[2] < 32) && (this->smonth > 0))
       this->sday = dd[2];
     else
-      ththrow("invalid date day -- \"{}\"", osrc);
+      throw thexception(fmt::format("invalid date day -- \"{}\"", osrc));
   }
 
   if (dd[3] >= 0) {
     if ((dd[3] < 24) && (this->sday > 0))
       this->shour = dd[3];
     else
-      ththrow("invalid date hour -- \"{}\"", osrc);
+      throw thexception(fmt::format("invalid date hour -- \"{}\"", osrc));
   }
 
   if (dd[4] >= 0) {
     if ((dd[4] < 60) && (this->shour >= 0))
       this->smin = dd[4];
     else
-      ththrow("invalid date minute -- \"{}\"", osrc);
+      throw thexception(fmt::format("invalid date minute -- \"{}\"", osrc));
   }
 
   if (dd[5] >= 0) {
     if ((dd[5] < 60) && (this->smin >= 0))
       this->ssec = (double) dd[5];
     else
-      ththrow("invalid date second -- \"{}\"", osrc);
+      throw thexception(fmt::format("invalid date second -- \"{}\"", osrc));
   }
   
   if (ss[0] > 0) {
@@ -220,49 +223,49 @@ void thdate::parse(const char * src)
       this->ssec += ss[0] / sm[0];
     }
     else
-      ththrow("invalid date second -- \"{}\"", osrc);
+      throw thexception(fmt::format("invalid date second -- \"{}\"", osrc));
   }
 
   if (dd[7] >= 0) {
     if (this->syear >= 0)
       this->eyear = dd[7];
     else
-      ththrow("start date must be specified -- \"{}\"", osrc);
+      throw thexception(fmt::format("start date must be specified -- \"{}\"", osrc));
   }
     
   if (dd[8] > 0) {
     if ((dd[8] < 13) && (this->eyear >= 0))
       this->emonth = dd[8];
     else
-      ththrow("invalid date month -- \"{}\"", osrc);
+      throw thexception(fmt::format("invalid date month -- \"{}\"", osrc));
   }
   
   if (dd[9] > 0) {
     if ((dd[9] < 32) && (this->emonth > 0))
       this->eday = dd[9];
     else
-      ththrow("invalid date day -- \"{}\"", osrc);
+      throw thexception(fmt::format("invalid date day -- \"{}\"", osrc));
   }
 
   if (dd[10] >= 0) {
     if ((dd[10] < 24) && (this->eday > 0))
       this->ehour = dd[10];
     else
-      ththrow("invalid date hour -- \"{}\"", osrc);
+      throw thexception(fmt::format("invalid date hour -- \"{}\"", osrc));
   }
 
   if (dd[11] >= 0) {
     if ((dd[11] < 60) && (this->ehour >= 0))
       this->emin = dd[11];
     else
-      ththrow("invalid date minute -- \"{}\"", osrc);
+      throw thexception(fmt::format("invalid date minute -- \"{}\"", osrc));
   }
 
   if (dd[12] >= 0) {
     if ((dd[12] < 60) && (this->emin >= 0))
       this->esec = (double) dd[12];
     else
-      ththrow("invalid date second -- \"{}\"", osrc);
+      throw thexception(fmt::format("invalid date second -- \"{}\"", osrc));
   }
   
   if (ss[1] > 0) {
@@ -272,7 +275,7 @@ void thdate::parse(const char * src)
       this->esec += ss[1] / sm[1];
     }
     else
-      ththrow("invalid date second -- \"{}\"", osrc);
+      throw thexception(fmt::format("invalid date second -- \"{}\"", osrc));
   }
   
 }  // parse
@@ -444,7 +447,7 @@ void thdate::join(thdate & dt)
 
 char * thdate::get_str(int fmt) {
   this->print_str(fmt);
-  return this->dstr.begin();
+  return this->dstr.data();
 }
 
 
@@ -602,7 +605,7 @@ void date2tm(int y, int m, int d, int hh, int mm, double ss, tm * info)
 void thdate::print_str(int fmt) {
   unsigned int tl = thdate_bufflen - 1;
   long yyyy, mm, dd;
-  char * dst = this->dstr.begin();
+  char * dst = this->dstr.data();
   const char * sep = " - ";
   const char * sep_ymd = "-"; // YYYY-MM-DD
   const char * sep_time = "T";
