@@ -21,7 +21,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA
  * --------------------------------------------------------------------
  */
  
@@ -413,11 +413,13 @@ void thexpshp::xscrap2d(thscrap * scrap, thdb2dxm * xmap, thdb2dxs * /*xbasic*/)
   slp = scrap->get_polygon();
   while (slp != NULL) {
     if (slp->lnio) {
-      this->m_flines.point_insert(slp->lnx1 + scrap->proj->rshift_x, slp->lny1 + scrap->proj->rshift_y, slp->lnz1 + scrap->proj->rshift_z);
-      this->m_flines.point_insert(slp->lnx2 + scrap->proj->rshift_x, slp->lny2 + scrap->proj->rshift_y, slp->lnz2 + scrap->proj->rshift_z);
-      this->m_flines.object_insert();
-	  this->m_flines.m_attributes.insert_attribute("_SCRAP_ID",(long) scrap->id);
-      this->m_flines.m_attributes.insert_attribute("_TYPE","centerline");
+  	  if (((slp->arrow != NULL) && ((slp->arrow->leg->leg->flags & TT_LEGFLAG_SPLAY) == 0)) || scrap->centerline_io) {
+  		  this->m_flines.point_insert(slp->lnx1 + scrap->proj->rshift_x, slp->lny1 + scrap->proj->rshift_y, slp->lnz1 + scrap->proj->rshift_z);
+  		  this->m_flines.point_insert(slp->lnx2 + scrap->proj->rshift_x, slp->lny2 + scrap->proj->rshift_y, slp->lnz2 + scrap->proj->rshift_z);
+  		  this->m_flines.object_insert();
+  		  this->m_flines.m_attributes.insert_attribute("_SCRAP_ID",(long) scrap->id);
+  		  this->m_flines.m_attributes.insert_attribute("_TYPE","centerline");
+      }
     } else {
       this->m_fpoints.point_insert(slp->stx + scrap->proj->rshift_x,  slp->sty + scrap->proj->rshift_y,  slp->stz + scrap->proj->rshift_z);
       this->m_fpoints.object_insert();
@@ -475,8 +477,8 @@ void thexpshp::xscrap2d(thscrap * scrap, thdb2dxm * xmap, thdb2dxs * /*xbasic*/)
         switch (ppt->type) {
           case TT_POINT_TYPE_LABEL:
           case TT_POINT_TYPE_REMARK:
-            if ((ppt->text != NULL) && (strlen(ppt->text) > 0))
-              this->m_fpoints.m_attributes.insert_attribute("_TEXT",ppt->text);
+            if (const auto* text = ppt->get_text(); text != nullptr && !text->empty())
+              this->m_fpoints.m_attributes.insert_attribute("_TEXT", text->c_str());
             break;
           case TT_POINT_TYPE_STATION:
             if (ppt->station_name.id > 0) {
