@@ -22,7 +22,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA
  * --------------------------------------------------------------------
  */
  
@@ -211,7 +211,8 @@ class thimport : public thdataobject {
 
   bool import_shot(struct thsst const & s1s, //
                    struct thsst const & s2s, //
-                   struct thimg_shot const * sli);
+                   struct thimg_shot const * sli,
+                   thsurvey * survey);
 
   void parse_calib(char * spec, int enc);
   
