@@ -34,6 +34,8 @@
 #include "thscrap.h"
 #include "thdatabase.h"
 
+#include <fmt/core.h>
+
 thline::thline()
 {
   this->type = TT_LINE_TYPE_UNKNOWN;
@@ -125,19 +127,19 @@ void thline::set(thcmd_option_desc cod, char ** args, int argenc, unsigned long
     case TT_LINE_OUTLINE:
       this->outline = thmatch_token(*args,thtt_line_outlines);
       if (this->outline == TT_LINE_OUTLINE_UNKNOWN)
-        ththrow("unknown line outline -- {}",*args);
+        throw thexception(fmt::format("unknown line outline -- {}",*args));
       break;
 
     case TT_LINE_CLOSED:
       this->closed = thmatch_token(*args,thtt_onoffauto);
       if (this->closed == TT_UNKNOWN_BOOL)
-        ththrow("invalid closure switch -- {}",*args);
+        throw thexception(fmt::format("invalid closure switch -- {}",*args));
       break;
 
     case TT_LINE_REVERSE:
       reversion = thmatch_token(*args,thtt_bool);
       if (reversion == TT_UNKNOWN_BOOL)
-        ththrow("invalid reversion switch -- {}",*args);
+        throw thexception(fmt::format("invalid reversion switch -- {}",*args));
       this->reverse = (reversion == TT_TRUE);
       break;
 
@@ -181,28 +183,28 @@ void thline::set(thcmd_option_desc cod, char ** args, int argenc, unsigned long
     case TT_LINE_SMOOTH:
       csmooth = thmatch_token(*args,thtt_onoffauto);
       if (csmooth == TT_UNKNOWN_BOOL)
-        ththrow("invalid smooth switch -- {}",*args);
+        throw thexception(fmt::format("invalid smooth switch -- {}",*args));
       if (this->last_point != NULL) {
         this->last_point->smooth = csmooth;
         this->last_point->smooth_orig = csmooth;
       }
       else
-        ththrow("no line point specified");
+        throw thexception("no line point specified");
       break;
 
     case TT_LINE_ORIENT:
       if (this->last_point != NULL) {
         if (this->type != TT_LINE_TYPE_SLOPE)
-          ththrow("orientation not valid with type {}", thmatch_string(this->type,thtt_line_types));
+          throw thexception(fmt::format("orientation not valid with type {}", thmatch_string(this->type,thtt_line_types)));
         thparse_double(sv,this->last_point->orient,*args);
         if ((sv != TT_SV_NUMBER) && (sv != TT_SV_NAN))
-          ththrow("invalid number -- {}",*args);
+          throw thexception(fmt::format("invalid number -- {}",*args));
         if ((this->last_point->orient < 0.0) || (this->last_point->orient >= 360.0))
-          ththrow("orientation out of range -- {}",*args);
+          throw thexception(fmt::format("orientation out of range -- {}",*args));
         this->last_point->tags |= TT_LINEPT_TAG_ORIENT;
       }
       else
-        ththrow("no line point specified");
+        throw thexception("no line point specified");
       break;
 
     case TT_LINE_SIZE:
@@ -218,11 +220,11 @@ void thline::set(thcmd_option_desc cod, char ** args, int argenc, unsigned long
     case TT_LINE_ANCHORS:
     case TT_LINE_REBELAYS:
       if (this->type != TT_LINE_TYPE_ROPE)
-        ththrow("-anchors and -rebelays not valid with type {}", thmatch_string(this->type,thtt_line_types));
+        throw thexception(fmt::format("-anchors and -rebelays not valid with type {}", thmatch_string(this->type,thtt_line_types)));
       int flag, tagtype;
       flag = thmatch_token(*args,thtt_bool);
       if (flag == TT_UNKNOWN_BOOL)
-        ththrow("logical value expected -- {}",*args);
+        throw thexception(fmt::format("logical value expected -- {}",*args));
       tagtype = (cod.id == TT_LINE_ANCHORS) ? TT_LINE_TAG_ROPE_ANCHORS : TT_LINE_TAG_ROPE_REBELAYS;
       if (flag == TT_TRUE)
         this->tags |= tagtype;
@@ -272,7 +274,7 @@ void thline::parse_type(char * ss)
   this->type = thmatch_token(ss,thtt_line_types);
   switch (this->type) {
     case TT_LINE_TYPE_UNKNOWN:
-      ththrow("unknown line type -- {}",ss);
+      throw thexception(fmt::format("unknown line type -- {}",ss));
       break;
     case TT_LINE_TYPE_WALL:
       this->csubtype = TT_LINE_SUBTYPE_BEDROCK;
@@ -312,13 +314,13 @@ void thline::parse_subtype(char * ss)
 //  int prevcsubtype = this->csubtype;
   if (this->type == TT_LINE_TYPE_U) {
     if (this->last_point != NULL)
-      ththrow("subtype specification not allowed here");
+      throw thexception("subtype specification not allowed here");
     this->parse_u_subtype(ss);
     return;
   }
   this->csubtype = thmatch_token(ss,thtt_line_subtypes);
   if (this->csubtype == TT_LINE_SUBTYPE_UNKNOWN)
-    ththrow("invalid line subtype -- {}",ss);
+    throw thexception(fmt::format("invalid line subtype -- {}",ss));
 //  if ((this->last_point != NULL) && (prevcsubtype != TT_LINE_SUBTYPE_UNKNOWN)
 //       && (this->csubtype != prevcsubtype)) {
 //    this->throw_source();
@@ -372,7 +374,7 @@ void thline::parse_subtype(char * ss)
       break;
   }
   if (!tsok)
-    ththrow("invalid line type - subtype combination");
+    throw thexception("invalid line type - subtype combination");
   if (this->last_point != NULL)
     this->last_point->subtype = this->csubtype;
 }
@@ -383,7 +385,7 @@ void thline::insert_line_point(int nargs, char ** args, double * nums)
 {
   // check number of parameters
   if ((nargs != 6) && (nargs != 2))
-    ththrow("invalid number of coordinates -- {}", nargs);
+    throw thexception(fmt::format("invalid number of coordinates -- {}", nargs));
 
   double cp1x, cp1y, cp2x, cp2y, x, y;
   int pidx = 0, sv;
@@ -437,7 +439,7 @@ void thline::insert_line_point(int nargs, char ** args, double * nums)
   }
 
   if (invnum)
-    ththrow("invalid number -- {}",invs);
+    throw thexception(fmt::format("invalid number -- {}",invs));
 
   // let's insert point into database
   thdb2dlp * plp = this->db->db2d.insert_line_point();
@@ -488,9 +490,9 @@ void thline::insert_line_point(int nargs, char ** args, double * nums)
 void thline::insert_point_mark(char * ss)
 {
   if (!th_is_keyword(ss))
-    ththrow("mark not a key word -- {}",ss);
+    throw thexception(fmt::format("mark not a key word -- {}",ss));
   if (this->last_point == NULL)
-    ththrow("no line point specified");
+    throw thexception("no line point specified");
   this->last_point->mark = this->db->strstore(ss,true);
 }
 
@@ -1207,10 +1209,10 @@ unsigned thline::export_path_mp(class thexpmapmpxs * out,
 void thline::parse_border(char * ss) {
   int bd;
   if (this->type != TT_LINE_TYPE_SLOPE)
-    ththrow("-border not valid with type {}", thmatch_string(this->type,thtt_line_types));
+    throw thexception(fmt::format("-border not valid with type {}", thmatch_string(this->type,thtt_line_types)));
   bd = thmatch_token(ss,thtt_bool);
   if (bd == TT_UNKNOWN_BOOL)
-    ththrow("logical value expected -- {}",ss);
+    throw thexception(fmt::format("logical value expected -- {}",ss));
   if (bd == TT_TRUE)
     this->tags |= TT_LINE_TAG_BORDER;
   else
@@ -1241,7 +1243,7 @@ static const thstok thtt_line_gradient[] = {
 void thline::parse_gradient(char * ss) {
   int gd;
   if (this->type != TT_LINE_TYPE_CONTOUR)
-    ththrow("-gradient not valid with type {}", thmatch_string(this->type,thtt_line_types));
+    throw thexception(fmt::format("-gradient not valid with type {}", thmatch_string(this->type,thtt_line_types)));
   gd = thmatch_token(ss,thtt_line_gradient);
   switch (gd) {
     case TT_LINE_GRADIENT_NONE:
@@ -1254,13 +1256,13 @@ void thline::parse_gradient(char * ss) {
       break;
     case TT_LINE_GRADIENT_POINT:
       if (this->last_point == NULL)
-        ththrow("no line point specified");
+        throw thexception("no line point specified");
       this->tags &= ~(TT_LINE_TAG_GRADIENT_NONE | TT_LINE_TAG_GRADIENT_CENTER | TT_LINE_TAG_GRADIENT_POINT);
       this->tags |= TT_LINE_TAG_GRADIENT_POINT;
       this->last_point->tags |= TT_LINEPT_TAG_GRADIENT;
       break;
     default:
-      ththrow("invalid gradient specification -- {}",ss);
+      throw thexception(fmt::format("invalid gradient specification -- {}",ss));
       break;
   }
 }
@@ -1269,7 +1271,7 @@ void thline::parse_gradient(char * ss) {
 void thline::parse_direction(char * ss) {
   int gd;
   if (this->type != TT_LINE_TYPE_SECTION)
-    ththrow("-direction not valid with type {}", thmatch_string(this->type,thtt_line_types));
+    throw thexception(fmt::format("-direction not valid with type {}", thmatch_string(this->type,thtt_line_types)));
   gd = thmatch_token(ss,thtt_line_gradient);
   switch (gd) {
     case TT_LINE_GRADIENT_NONE:
@@ -1289,13 +1291,13 @@ void thline::parse_direction(char * ss) {
       break;
     case TT_LINE_GRADIENT_POINT:
       if (this->last_point == NULL)
-        ththrow("no line point specified");
+        throw thexception("no line point specified");
       this->tags &= ~(TT_LINE_TAG_DIRECTION_BEGIN | TT_LINE_TAG_DIRECTION_END);
       this->tags |= TT_LINE_TAG_DIRECTION_POINT;
       this->last_point->tags |= TT_LINEPT_TAG_DIRECTION;
       break;
     default:
-      ththrow("invalid direction specification -- {}",ss);
+      throw thexception(fmt::format("invalid direction specification -- {}",ss));
       break;
   }
 }
@@ -1306,7 +1308,7 @@ void thline::parse_direction(char * ss) {
 void thline::parse_head(char * ss) {
   int gd;
   if (this->type != TT_LINE_TYPE_ARROW)
-    ththrow("-direction not valid with type {}", thmatch_string(this->type,thtt_line_types));
+    throw thexception(fmt::format("-direction not valid with type {}", thmatch_string(this->type,thtt_line_types)));
   gd = thmatch_token(ss,thtt_line_gradient);
   this->tags &= ~(TT_LINE_TAG_HEAD_BEGIN | TT_LINE_TAG_HEAD_END);
   switch (gd) {
@@ -1322,7 +1324,7 @@ void thline::parse_head(char * ss) {
       this->tags |= TT_LINE_TAG_HEAD_END | TT_LINE_TAG_HEAD_BEGIN;
       break;
     default:
-      ththrow("invalid head specification -- {}",ss);
+      throw thexception(fmt::format("invalid head specification -- {}",ss));
       break;
   }
 }
@@ -1332,12 +1334,12 @@ void thline::parse_adjust(char * ss) {
   if (this->last_point != NULL)
     this->last_point->adjust = thmatch_token(ss,thtt_line_adjusts);
   else
-    ththrow("no line point specified");
+    throw thexception("no line point specified");
   if (this->last_point->adjust == TT_LINE_ADJUST_UNKNOWN)
-    ththrow("invalid adjust specification -- {}",ss);
+    throw thexception(fmt::format("invalid adjust specification -- {}",ss));
   if ((thdb.cscrapptr->proj->type == TT_2DPROJ_PLAN) &&
       (this->last_point->adjust != TT_LINE_ADJUST_NONE))
-    ththrow("adjustment and projection not compatible -- {}",ss);
+    throw thexception(fmt::format("adjustment and projection not compatible -- {}",ss));
 }
 
 
@@ -1345,7 +1347,7 @@ void thline::parse_size(int w, char * ss) {
   int sv;
   double sz;
   if (this->last_point == NULL)
-    ththrow("no line point specified");
+    throw thexception("no line point specified");
   const char * sizestr = NULL;
   switch (w) {
     case TT_LINE_SIZE:
@@ -1366,14 +1368,14 @@ void thline::parse_size(int w, char * ss) {
       break;
   }
   if (!ok)
-    ththrow("{} not valid with type {}", sizestr,
-        thmatch_string(this->type,thtt_line_types));
+    throw thexception(fmt::format("{} not valid with type {}", sizestr,
+        thmatch_string(this->type,thtt_line_types)));
 
   thparse_double(sv,sz,ss);
   if (sv != TT_SV_NUMBER)
-    ththrow("invalid number -- {}",ss);
+    throw thexception(fmt::format("invalid number -- {}",ss));
   if (sz < 0.0)
-    ththrow("negative size -- {}",ss);
+    throw thexception(fmt::format("negative size -- {}",ss));
 
   switch (this->type) {
     case TT_LINE_TYPE_SLOPE:
@@ -1387,10 +1389,10 @@ void thline::parse_size(int w, char * ss) {
 void thline::parse_altitude(char * ss) {
 
   if (this->type != TT_LINE_TYPE_WALL)
-    ththrow("-altitude not valid with type {}", thmatch_string(this->type,thtt_line_types));
+    throw thexception(fmt::format("-altitude not valid with type {}", thmatch_string(this->type,thtt_line_types)));
 
   if (this->last_point == NULL)
-    ththrow("no line point specified");
+    throw thexception("no line point specified");
 
   thparse_altitude(ss, this->last_point->rsize, this->last_point->lsize);
 
@@ -1399,7 +1401,7 @@ void thline::parse_altitude(char * ss) {
 
 void thline::parse_text(char * ss) {
   if (this->type != TT_LINE_TYPE_LABEL)
-    ththrow("-text not valid with type {}", thmatch_string(this->type,thtt_line_types));
+    throw thexception(fmt::format("-text not valid with type {}", thmatch_string(this->type,thtt_line_types)));
   if (strlen(ss) > 0)
     this->text = this->db->strstore(ss);
 }
@@ -1413,7 +1415,7 @@ void thline::start_insert() {
   switch (this->type) {
     case TT_LINE_TYPE_U:
       if (this->m_subtype_str == NULL)
-        ththrow("missing subtype specification for line of user defined type");
+        throw thexception("missing subtype specification for line of user defined type");
       this->db->db2d.register_u_symbol(this->get_class_id(), this->m_subtype_str);
       break;
     case TT_LINE_TYPE_SLOPE:
@@ -1427,7 +1429,7 @@ void thline::start_insert() {
         lp = lp->nextlp;
       }
       if (fsize)
-        ththrow("no slope size specification at any line point");
+        throw thexception("no slope size specification at any line point");
       break;
   }
 }
@@ -1445,7 +1447,7 @@ void thline::parse_height(char * ss) {
 		  break;
     [[fallthrough]];
     default:
-      ththrow("-height not valid with type {}", thmatch_string(this->type,thtt_line_types));
+      throw thexception(fmt::format("-height not valid with type {}", thmatch_string(this->type,thtt_line_types)));
       break;
   }
 
@@ -1464,14 +1466,14 @@ void thline::parse_height(char * ss) {
       ux = 1;
       break;
     default:
-      ththrow("invalid distance -- {}",ss);
+      throw thexception(fmt::format("invalid distance -- {}",ss));
   }
   this->m_height = thnan;
   thparse_double(sv,dv,pars[0]);
   if (sv != TT_SV_NUMBER)
-    ththrow("not a number -- {}", pars[0]);
+    throw thexception(fmt::format("not a number -- {}", pars[0]));
   if (dv <= 0.0)
-	ththrow("nor a positivie number -- {}", pars[0]);
+	throw thexception(fmt::format("nor a positivie number -- {}", pars[0]));
   if (ux > 0) {
     lentf.parse_units(pars[ux]);
     dv = lentf.transform(dv);
