@@ -17,7 +17,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA
  * --------------------------------------------------------------------
  */
  
@@ -30,11 +30,13 @@
 #include <proj.h>
 
 enum {GRID_INVALID, GRID_IGNORE, GRID_WARN, GRID_FAIL, GRID_CACHE, GRID_DOWNLOAD};
+enum class axis_orient {NORTH, SOUTH, WEST, EAST, OTHER};
 
 void thcs2cs(int, int, double, double, double, double &, double &, double &);
 signed int thcs2zone(int, double, double, double);
 double thcsconverg(int, double, double);
 bool thcs_islatlong(std::string);
+std::vector<axis_orient> thcs_axesinfo(int, double &, bool &);
 bool thcs_check(std::string);
 void thcs_log_transf_used();
 int thcs_parse_gridhandling(const char *);
