@@ -78,11 +78,11 @@ void thselector::parse_selection (bool usid, int nargs, char ** args)
   thselector_item itm;
   itm.unselect = usid;
   if (nargs < 1)
-    ththrow("not enough command arguments");
+    throw thexception("not enough command arguments");
 
   // set object name
   if (strlen(*args) == 0)
-    ththrow("empty object name not allowed");
+    throw thexception("empty object name not allowed");
   itm.name = this->cfgptr->get_str_buff()->append(*args);
   itm.src_name = this->cfgptr->get_db()->strstore(this->cfgptr->get_cfg_file()->get_cif_name(), true);
   itm.src_ln = this->cfgptr->get_cfg_file()->get_cif_line_number();
@@ -103,7 +103,7 @@ void thselector::parse_selection (bool usid, int nargs, char ** args)
             itm.recursive = true;
             break;
           case TT_UNKNOWN_BOOL:
-            ththrow("logical value expected -- {}", args[aid]);
+            throw thexception(fmt::format("logical value expected -- {}", args[aid]));
         }
         break;
 
@@ -120,9 +120,9 @@ void thselector::parse_selection (bool usid, int nargs, char ** args)
           break;
         }
         if ((sv != TT_SV_NUMBER) || (dum < 0))
-          ththrow("invalid map level -- {}", *args);
+          throw thexception(fmt::format("invalid map level -- {}", *args));
         if (double(int(dum)) != dum)
-          ththrow("invalid map level -- {}", *args);
+          throw thexception(fmt::format("invalid map level -- {}", *args));
         itm.map_level = long(dum);
         break;
 
@@ -134,14 +134,14 @@ void thselector::parse_selection (bool usid, int nargs, char ** args)
           break;
         }
         if ((sv != TT_SV_NUMBER) || (dum <= 0))
-          ththrow("invalid chapter level -- {}", *args);
+          throw thexception(fmt::format("invalid chapter level -- {}", *args));
         if (double(int(dum)) != dum)
-          ththrow("invalid chapter level -- {}", *args);
+          throw thexception(fmt::format("invalid chapter level -- {}", *args));
         itm.chapter_level = long(dum);
         break;
         
       default:
-        ththrow("unknown option -- {}", args[aid]);
+        throw thexception(fmt::format("unknown option -- {}", args[aid]));
     }
   }
   
