@@ -177,10 +177,10 @@ void thsurface::set(thcmd_option_desc cod, char ** args, int argenc, unsigned lo
     
     case TT_SURFACE_GRID_FLIP:
       if (this->grid != NULL)
-        ththrow("grid-flip specification after grid data not allowed");
+        throw thexception("grid-flip specification after grid data not allowed");
       this->grid_flip = thmatch_token(args[0], thtt_surface_gflip);
       if (this->grid_flip == TT_SURFACE_GFLIP_UNKNOWN)
-        ththrow("unknown surface flip mode -- {}", args[0]);
+        throw thexception(fmt::format("unknown surface flip mode -- {}", args[0]));
       break;
       
     case TT_SURFACE_PICTURE:
@@ -207,7 +207,7 @@ void thsurface::self_print_properties(FILE * outf)
 void thsurface::parse_picture(char ** args)
 {
   if (strlen(args[0]) == 0)
-    ththrow("picture name not specified");
+    throw thexception("picture name not specified");
 
   std::error_code ec;
   auto pict_path = fs::current_path(ec);
@@ -255,7 +255,7 @@ void thsurface::parse_picture(char ** args)
 #define surfpiccaldbl(XXX,YYY) \
       thparse_double(sv, this->XXX, cals[YYY]); \
       if (sv != TT_SV_NUMBER) \
-        ththrow("number expected -- {}", cals[YYY]);
+        throw thexception(fmt::format("number expected -- {}", cals[YYY]));
       
       surfpiccaldbl(pict_X1,0);
       surfpiccaldbl(pict_Y1,1);
@@ -275,7 +275,7 @@ void thsurface::parse_picture(char ** args)
       
       if (((this->pict_X1 == this->pict_X2) && (this->pict_Y1 == this->pict_Y2)) ||
           ((this->pict_x1 == this->pict_x2) && (this->pict_y1 == this->pict_y2))) {
-        ththrow("duplicate points in picture calibration");
+        throw thexception("duplicate points in picture calibration");
       }
       break;
     
@@ -288,12 +288,12 @@ void thsurface::parse_picture(char ** args)
       thparse_objectname(this->s2, &(thdb.buff_stations), cals[5]);
       this->ssurvey = thdb.get_current_survey();
       if ((this->pict_X1 == this->pict_X2) && (this->pict_Y1 == this->pict_Y2)) {
-        ththrow("duplicate points in picture calibration");
+        throw thexception("duplicate points in picture calibration");
       }
       break;
 
     default:
-      ththrow("invalid number of picture calibration arguments -- {}", ncals);
+      throw thexception(fmt::format("invalid number of picture calibration arguments -- {}", ncals));
   }
 
 }
@@ -337,17 +337,17 @@ void thsurface::check_stations()
     this->s1.id = thdb.db1d.get_station_id(this->s1, this->ssurvey);
     if (this->s1.id == 0) {
       if (this->s1.survey == NULL)
-        ththrow("{} -- station doesn't exist -- {}", this->throw_source(), this->s1.name);
+        throw thexception(fmt::format("{} -- station doesn't exist -- {}", this->throw_source(), this->s1.name));
       else
-        ththrow("{} -- station doesn't exist -- {}@{}", this->throw_source(), this->s1.name, this->s1.survey);
+        throw thexception(fmt::format("{} -- station doesn't exist -- {}@{}", this->throw_source(), this->s1.name, this->s1.survey));
     }
     
     this->s2.id = thdb.db1d.get_station_id(this->s2, this->ssurvey);
     if (this->s2.id == 0) {
       if (this->s2.survey == NULL)
-        ththrow("{} -- station doesn't exist -- {}", this->throw_source(), this->s2.name);
+        throw thexception(fmt::format("{} -- station doesn't exist -- {}", this->throw_source(), this->s2.name));
       else
-        ththrow("{} -- station doesn't exist -- {}@{}", this->throw_source(), this->s2.name, this->s2.survey);
+        throw thexception(fmt::format("{} -- station doesn't exist -- {}@{}", this->throw_source(), this->s2.name, this->s2.survey));
     }
     
     // priradi si x a y a skontroluje ci su roozne
@@ -358,7 +358,7 @@ void thsurface::check_stations()
     this->pict_x2 = ds2->x;
     this->pict_y2 = ds2->y;
     if ((this->pict_x1 == this->pict_x2) && (this->pict_y1 == this->pict_y2)) {
-      ththrow("{} -- duplicate points in picture calibration", this->throw_source());
+      throw thexception(fmt::format("{} -- duplicate points in picture calibration", this->throw_source()));
     }
   }
 }
@@ -367,7 +367,7 @@ void thsurface::check_stations()
 void thsurface::parse_grid_setup(char ** args)
 {
   if (this->grid != NULL)
-    ththrow("grid specification after grid data not allowed");
+    throw thexception("grid specification after grid data not allowed");
 
   // nacitame vsetky premenne ktore treba
   double dblv;
@@ -376,30 +376,30 @@ void thsurface::parse_grid_setup(char ** args)
 #define parsedbl(XXX,YYY) \
       thparse_double(sv, dblv, args[YYY]); \
       if (sv != TT_SV_NUMBER) \
-        ththrow("number expected -- {}", args[YYY]); \
+        throw thexception(fmt::format("number expected -- {}", args[YYY])); \
       XXX = this->grid_units.transform(dblv);
 #define parsenum(XXX,YYY) \
       thparse_double(sv, dblv, args[YYY]); \
       if (sv != TT_SV_NUMBER) \
-        ththrow("number expected -- {}", args[YYY]); \
+        throw thexception(fmt::format("number expected -- {}", args[YYY])); \
       if (dblv <= 0) \
-        ththrow("positive number expected -- {}", args[YYY]); \
+        throw thexception(fmt::format("positive number expected -- {}", args[YYY])); \
       if (dblv != double(long(dblv))) \
-        ththrow("integer expected -- {}", args[YYY]); \
+        throw thexception(fmt::format("integer expected -- {}", args[YYY])); \
       XXX = long(dblv);
   
   parsedbl(this->grid_dx,2);
   if (this->grid_dx == 0.0)
-    ththrow("non-zero number expected -- {}", args[2]);
+    throw thexception(fmt::format("non-zero number expected -- {}", args[2]));
   parsedbl(this->grid_dy,3);
   if (this->grid_dy == 0.0)
-    ththrow("non-zero number expected -- {}", args[3]);
+    throw thexception(fmt::format("non-zero number expected -- {}", args[3]));
   parsenum(this->grid_nx,4);
   if (this->grid_nx < 2)
-    ththrow("number > 1 expected -- {}", args[4]);
+    throw thexception(fmt::format("number > 1 expected -- {}", args[4]));
   parsenum(this->grid_ny,5);
   if (this->grid_ny < 2)
-    ththrow("number > 1 expected -- {}", args[5]);
+    throw thexception(fmt::format("number > 1 expected -- {}", args[5]));
 
   this->grid_cs = this->cs;
   this->read_cs(args[0], args[1], this->grid_ox, this->grid_oy);
@@ -428,7 +428,7 @@ void thsurface::parse_grid_setup(char ** args)
 void thsurface::parse_grid(char * spec)
 {
   if (this->grid_nx == 0)
-    ththrow("grid dimensions not specified");
+    throw thexception("grid dimensions not specified");
   if (this->grid == NULL) {
     this->grid_counter = 0;
     this->grid_size = this->grid_nx * this->grid_ny;
@@ -447,9 +447,9 @@ void thsurface::parse_grid(char * spec)
   for(i = 0; i < ni; i++) {
     thparse_double(sv, alt, heights[i]);
     if (sv != TT_SV_NUMBER)
-      ththrow("number expected -- {}", heights[i]);
+      throw thexception(fmt::format("number expected -- {}", heights[i]));
     if (this->grid_counter == this->grid_size)
-      ththrow("too many grid data");
+      throw thexception("too many grid data");
     x = this->grid_counter % this->grid_nx;
     y = this->grid_ny - (this->grid_counter / this->grid_nx) - 1;
     switch (this->grid_flip) {
@@ -467,7 +467,7 @@ void thsurface::parse_grid(char * spec)
 
 void thsurface::start_insert() {
   if (this->grid_counter < this->grid_size)
-    ththrow("missing grid data");
+    throw thexception("missing grid data");
 }
 
 thdb3ddata * thsurface::get_3d() {
