@@ -33,6 +33,8 @@
 #include "thinfnan.h"
 #include "thdatabase.h"
 
+#include <fmt/core.h>
+
 thsurvey::thsurvey()
 {
   this->full_name = "";
@@ -151,7 +153,7 @@ void thsurvey::set(thcmd_option_desc cod, char ** args, int argenc, unsigned lon
           break;
 
         default:
-          ththrow("invalid -namespace switch -- {}", *args);
+          throw thexception(fmt::format("invalid -namespace switch -- {}", *args));
 
       }
       break;
@@ -176,7 +178,7 @@ void thsurvey::set(thcmd_option_desc cod, char ** args, int argenc, unsigned lon
       if (th_is_keyword(*args))
         this->name = this->db->strstore(*args);
       else 
-        ththrow("invalid keyword -- {}", *args);
+        throw thexception(fmt::format("invalid keyword -- {}", *args));
       break;
       
     default:
@@ -235,7 +237,7 @@ void thsurvey::parse_declination(char * str)
 
   // ak 1 4 6 ... error
   if ((nargs == 1) || (((nargs % 2) == 0) && (nargs > 3)))
-    ththrow("invalid declination specification -- \"{}\"",str);
+    throw thexception(fmt::format("invalid declination specification -- \"{}\"",str));
 
   // ak 0 tak resetuje a nastavi na 0
   if (nargs == 0) {
@@ -251,7 +253,7 @@ void thsurvey::parse_declination(char * str)
   if (nargs == 1) {
     thparse_double(nid, decl, args[0]);
     if (nid != TT_SV_NUMBER)
-      ththrow("invalid declination -- {}", args[0]);
+      throw thexception(fmt::format("invalid declination -- {}", args[0]));
     decl = du.transform(decl);
     data2[0] = 0.0;
     data2[1] = decl;
@@ -271,7 +273,7 @@ void thsurvey::parse_declination(char * str)
     if (typedt == TT_SV_NAN) {
       thparse_double(nid, decl, args[2 * idx + 1]);
       if (nid != TT_SV_NUMBER) {
-        ththrow("invalid declination -- {}", args[2 * idx + 1]);
+        throw thexception(fmt::format("invalid declination -- {}", args[2 * idx + 1]));
       }
       this->decuds = decl;
     }
@@ -280,14 +282,14 @@ void thsurvey::parse_declination(char * str)
     else {
       try {
         dd.parse(args[2 * idx]);
-      } catch (...) {
-        threthrow("invalid declination specification");
+      } catch (const std::exception& e) {
+        throw thexception("invalid declination specification", e);
       }
       all_data[2 * dateidx] = dd.get_start_year();
       // parse declination
       thparse_double(nid, decl, args[2 * idx + 1]);
       if (nid != TT_SV_NUMBER) {
-        ththrow("invalid declination -- {}", args[2 * idx + 1]);
+        throw thexception(fmt::format("invalid declination -- {}", args[2 * idx + 1]));
       }
       all_data[2 * dateidx + 1] = du.transform(decl);
       dateidx++;
@@ -348,7 +350,7 @@ thsurvey * thsurvey_get_entrance_fs(thsurvey * s) {
 
 thobjectname thsurvey::get_entrance() {
 	thsurvey * s(this);
-	while ((s != NULL) and s->entrance.is_empty()) s = s->fsptr;
+	while ((s != NULL) && s->entrance.is_empty()) s = s->fsptr;
 	if (s == NULL) s = thsurvey_get_entrance_fs(this);
 	if (s == NULL) return thobjectname();
 	return s->entrance;
