@@ -14,7 +14,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA
  * --------------------------------------------------------------------
  */
  
@@ -26,5 +26,7 @@
 void thsvg(const char * fname, int, const legenddata& ldata);
 
 std::string escape_html(std::string);
+std::string sanitize_xml_id(const std::string&
+);
 
 #endif
