@@ -29,6 +29,9 @@
 #include "thexception.h"
 #include "thinfnan.h"
 #include "thparse.h"
+
+#include <fmt/core.h>
+
 #include <algorithm>
 
 
@@ -61,16 +64,16 @@ void thtfpwf::parse(int nfact, char ** sfact)
     case 1:
       thparse_double(sv, this->b, *sfact);
       if (sv != TT_SV_NUMBER)
-        ththrow("invalid number -- {}", *sfact);
+        throw thexception(fmt::format("invalid number -- {}", *sfact));
       this->a = 1.0;
       break;
     case 2:
       thparse_double(sv, this->b, sfact[0]);
       if (sv != TT_SV_NUMBER)
-        ththrow("invalid number -- {}", sfact[0]);
+        throw thexception(fmt::format("invalid number -- {}", sfact[0]));
       thparse_double(sv, this->a, sfact[1]);
       if (sv != TT_SV_NUMBER)
-        ththrow("invalid number -- {}", sfact[1]);
+        throw thexception(fmt::format("invalid number -- {}", sfact[1]));
       break;
     default:
       if ((nfact > 2) && ((nfact % 2) == 0)) {
@@ -79,15 +82,15 @@ void thtfpwf::parse(int nfact, char ** sfact)
         for(cidx = 0; cidx < nfact; cidx++) {
           thparse_double(spv,coefs[cidx],sfact[cidx]);
           if (spv == TT_SV_UNKNOWN)
-            ththrow("invalid number -- {}", sfact[cidx]);
+            throw thexception(fmt::format("invalid number -- {}", sfact[cidx]));
         }
         this->set(nfact / 2, coefs.data());
       }
       else
-        ththrow("invalid number of transformation constants");
+        throw thexception("invalid number of transformation constants");
   }
   if (this->a == 0.0)
-    ththrow("invalid scale factor -- {}", this->a);
+    throw thexception(fmt::format("invalid scale factor -- {}", this->a));
 }
   
 double thtfpwf::evaluate(double value)
