@@ -22,7 +22,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA
  * --------------------------------------------------------------------
  */
 #include <math.h>
@@ -588,15 +588,13 @@ thm2t_point_ptr thmorph2trans_members::get_extra_point(long id)
 
 thmorph2trans::thmorph2trans()
 {
-  this->m = new thmorph2trans_members;
+  this->m = std::make_unique<thmorph2trans_members>();
   this->reset();
 }
 
-thmorph2trans::~thmorph2trans()
-{
-  delete this->m;
-}
-
+// thmorph2trans_members is forward-declared in the header,
+// so the destructor of thmorph2trans must be defined in the cpp file
+thmorph2trans::~thmorph2trans() = default;
 
 void thmorph2trans::reset()
 {
