@@ -22,7 +22,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA
  * --------------------------------------------------------------------
  */
 #ifndef thtrans_2_h
@@ -36,6 +36,7 @@
 #include <string>
 #include <vector>
 #include <list>
+#include <memory>
 
 struct thline2; // forward declaration
 
@@ -266,7 +267,7 @@ struct thmorphtrans {
 
 struct thmorph2trans {
   
-  struct thmorph2trans_members * m;
+  std::unique_ptr<struct thmorph2trans_members> m;
   double m_eps = {};
 
   thmorph2trans();
