@@ -21,7 +21,7 @@
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
-* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA
 * --------------------------------------------------------------------
 */
 
@@ -173,8 +173,8 @@ thpic * thwarpp::morph(thsketch * sketch, double scale) {
 
   thvec2 origin( mw/2.0, mh/2.0	);
   double unit	=	TW.to_unit() * sf;
-  TW.map_image(	(const unsigned	char*)this->m_sketch->m_pic.rgba,	pw,	ph,
-    (unsigned	char*)this->mpic.rgba, mw, mh, 
+  TW.map_image(	(const unsigned	char*)this->m_sketch->m_pic.rgba.data(),	pw,	ph,
+    (unsigned	char*)this->mpic.rgba.data(), mw, mh, 
     origin,	unit,
     4	);
 
