@@ -22,14 +22,13 @@
 ## 
 ## You should have received a copy of the GNU General Public License
 ## along with this program; if not, write to the Free Software
-## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+## Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA
 ## --------------------------------------------------------------------
 
 set xth(debug) 1
 
 #@ALL
 source ver.tcl
-source ivc.tcl
 source global.tcl
 source msgxth.tcl
 source msgusr.tcl
@@ -51,17 +50,20 @@ source app.tcl
 source te.tcl
 source te_sdata.tcl
 source te_sdata2.tcl
+source te_import.tcl
 #@XTHERION
+source tools_imgs.tcl
 source me_imgs.tcl
 source me_cmds.tcl
 source me_cmds2.tcl
+source me_import.tcl
 source me_ss.tcl
 source me.tcl
 source cp_procs.tcl
 source bac.tcl
 source cp.tcl
-source mv.tcl
-source mv_procs.tcl
+source tools.tcl
+source mapcal.tcl
 #@DEBUG
 if {![string equal $xth(gui,platform) windows]} {
   source console.tcl
